@@ -9,8 +9,7 @@ import pathlib
 import numpy as np
 #from scipy.io import savemat
 
-from . import extraction, io, registration, detection, classification
-from .version import version
+from . import extraction, io, registration, detection, classification, default_ops
 
 try:
     from haussmeister import haussio
@@ -22,244 +21,125 @@ from functools import partial
 from pathlib import Path
 print = partial(print,flush=True)
 
-def default_ops():
-    """ default options to run pipeline """
-    return {
-        # Suite2p version
-        'suite2p_version': version,
+def pipeline(f_reg, f_raw=None, f_reg_chan2=None, f_raw_chan2=None, 
+             run_registration=True, ops=default_ops(), stat=None):
+    """ run suite2p processing on array or BinaryRWFile 
+    
+    f_reg: required, registered or unregistered frames
+        n_frames x Ly x Lx
 
-        # file input/output settings
-        'look_one_level_down': False,  # whether to look in all subfolders when searching for tiffs
-        'fast_disk': [],  # used to store temporary binary file, defaults to save_path0
-        'delete_bin': False,  # whether to delete binary file after processing
-        'mesoscan': False,  # for reading in scanimage mesoscope files
-        'bruker': False,  # whether or not single page BRUKER tiffs!
-        'bruker_bidirectional': False, # bidirectional multiplane in bruker: 0, 1, 2, 2, 1, 0 (True) vs 0, 1, 2, 0, 1, 2 (False)
-        'h5py': [],  # take h5py as input (deactivates data_path)
-        'h5py_key': 'data',  #key in h5py where data array is stored
-        'nwb_file': '', # take nwb file as input (deactivates data_path)
-        'nwb_driver': '', # driver for nwb file (nothing if file is local)
-        'nwb_series': '', # TwoPhotonSeries name, defaults to first TwoPhotonSeries in nwb file
-        'save_path0': [],  # stores results, defaults to first item in data_path
-        'save_folder': [],
-        'subfolders': [],
-        'move_bin': False,  # if 1, and fast_disk is different than save_disk, binary file is moved to save_disk
+    f_raw: optional, unregistered frames that will not be overwritten during registration
+        n_frames x Ly x Lx
 
-        # main settings
-        'nplanes' : 1,  # each tiff has these many planes in sequence
-        'nchannels' : 1,  # each tiff has these many channels per plane
-        'functional_chan' : 1,  # this channel is used to extract functional ROIs (1-based)
-        'tau':  1.,  # this is the main parameter for deconvolution
-        'fs': 10.,  # sampling rate (PER PLANE e.g. for 12 plane recordings it will be around 2.5)
-        'force_sktiff': False, # whether or not to use scikit-image for tiff reading
-        'frames_include': -1,
-        'multiplane_parallel': False, # whether or not to run on server
-        'ignore_flyback': [],
+    f_reg_chan2: optional, non-functional frames
+        n_frames x Ly x Lx
 
-        # output settings
-        'preclassify': 0.,  # apply classifier before signal extraction with probability 0.3
-        'save_mat': False,  # whether to save output as matlab files
-        'save_NWB': False,  # whether to save output as NWB file
-        'combined': True,  # combine multiple planes into a single result /single canvas for GUI
-        'aspect': 1.0,  # um/pixels in X / um/pixels in Y (for correct aspect ratio in GUI)
+    f_raw_chan2: optional, non-functional frames that will not be overwritten during registration
+        n_frames x Ly x Lx
 
-        # bidirectional phase offset
-        'do_bidiphase': False,
-        'bidiphase': 0,
-        'bidi_corrected': False,
+    run_registration: optional, default True
+        run registration
 
-        # registration settings
-        'do_registration': 1,  # whether to register data (2 forces re-registration)
-        'two_step_registration': False,
-        'keep_movie_raw': False,
-        'nimg_init': 300,  # subsampled frames for finding reference image
-        'batch_size': 500,  # number of frames per batch
-        'maxregshift': 0.1,  # max allowed registration shift, as a fraction of frame max(width and height)
-        'align_by_chan' : 1,  # when multi-channel, you can align by non-functional channel (1-based)
-        'reg_tif': False,  # whether to save registered tiffs
-        'reg_tif_chan2': False,  # whether to save channel 2 registered tiffs
-        'subpixel' : 10,  # precision of subpixel registration (1/subpixel steps)
-        'smooth_sigma_time': 0,  # gaussian smoothing in time
-        'smooth_sigma': 1.15,  # ~1 good for 2P recordings, recommend 3-5 for 1P recordings
-        'th_badframes': 1.0,  # this parameter determines which frames to exclude when determining cropping - set it smaller to exclude more frames
-        'norm_frames': True, # normalize frames when detecting shifts
-        'force_refImg': False, # if True, use refImg stored in ops if available
-        'pad_fft': False,
-        
-        # non rigid registration settings
-        'nonrigid': True,  # whether to use nonrigid registration
-        'block_size': [128, 128],  # block size to register (** keep this a multiple of 2 **)
-        'snr_thresh': 1.2,  # if any nonrigid block is below this threshold, it gets smoothed until above this threshold. 1.0 results in no smoothing
-        'maxregshiftNR': 5,  # maximum pixel shift allowed for nonrigid, relative to rigid
+    ops: optional, `dict` of settings
 
-        # 1P settings
-        '1Preg': False,  # whether to perform high-pass filtering and tapering
-        'spatial_hp': 42,  # window for spatial high-pass filtering before registration
-        'spatial_hp_reg': 42,  # window for spatial high-pass filtering before registration
-        'spatial_hp_detect': 25,  # window for spatial high-pass filtering for neuropil subtraction before detection
-        'pre_smooth': 0,  # whether to smooth before high-pass filtering before registration
-        'spatial_taper': 40,  # how much to ignore on edges (important for vignetted windows, for FFT padding do not set BELOW 3*ops['smooth_sigma'])
-
-        # cell detection settings
-        'roidetect': True,  # whether or not to run ROI extraction
-        'spikedetect': True,  # whether or not to run spike deconvolution
-        'anatomical_only': 0, # use cellpose masks from mean image (no functional segmentation)
-        'cellprob_threshold': 0.0, # cellprob_threshold for cellpose (if anatomical_only > 1)
-        'flow_threshold': 1.5, # flow_threshold for cellpose (if anatomical_only > 1)
-        'sparse_mode': True,  # whether or not to run sparse_mode
-        'diameter': 0,  # if anatomical_only, use diameter for cellpose, if 0 estimate diameter
-        'spatial_scale': 0,  # 0: multi-scale; 1: 6 pixels, 2: 12 pixels, 3: 24 pixels, 4: 48 pixels
-        'connected': True,  # whether or not to keep ROIs fully connected (set to 0 for dendrites)
-        'nbinned': 5000,  # max number of binned frames for cell detection
-        'max_iterations': 20,  # maximum number of iterations to do cell detection
-        'threshold_scaling': 1.0,  # adjust the automatically determined threshold by this scalar multiplier
-        'max_overlap': 0.75,  # cells with more overlap than this get removed during triage, before refinement
-        'high_pass': 100,  # running mean subtraction with window of size 'high_pass' (use low values for 1P)
-        'denoise': False, # denoise binned movie for cell detection in sparse_mode
-
-        # classification parameters
-        'soma_crop': True, # crop dendrites for cell classification stats like compactness
-        # ROI extraction parameters
-        'neuropil_extract': True, # whether or not to extract neuropil; if False, Fneu is set to zero
-        'inner_neuropil_radius': 2,  # number of pixels to keep between ROI and neuropil donut
-        'min_neuropil_pixels': 350,  # minimum number of pixels in the neuropil
-        'lam_percentile': 50., # percentile of lambda within area to ignore when excluding cell pixels for neuropil extraction
-        'allow_overlap': False,  # pixels that are overlapping are thrown out (False) or added to both ROIs (True)
-        'use_builtin_classifier': False,  # whether or not to use built-in classifier for cell detection (overrides
-                                         # classifier specified in classifier_path if set to True)
-        'classifier_path': 0, # path to classifier
-        
-        # channel 2 detection settings (stat[n]['chan2'], stat[n]['not_chan2'])
-        'chan2_thres': 0.65,  # minimum for detection of brightness on channel 2
-
-        # deconvolution settings
-        'baseline': 'maximin',  # baselining mode (can also choose 'prctile')
-        'win_baseline': 60.,  # window for maximin
-        'sig_baseline': 10.,  # smoothing constant for gaussian filter
-        'prctile_baseline': 8.,  # optional (whether to use a percentile baseline)
-        'neucoeff': .7,  # neuropil coefficient
-    }
-
-
-def run_plane(ops, ops_path=None, stat=None):
-    """ run suite2p processing on a single binary file
-
-    Parameters
-    -----------
-    ops : :obj:`dict` 
-        specify 'reg_file', 'nchannels', 'tau', 'fs'
-
-    ops_path: str
-        absolute path to ops file (use if files were moved)
-
-    Returns
-    --------
-    ops : :obj:`dict` 
+    stat: optional, input predefined masks
+    
     """
+    
+    plane_times = {}
     t1 = time.time()
     
-    ops = {**default_ops(), **ops}
-    ops['date_proc'] = datetime.now()
-    plane_times = {}
-    
-    # for running on server or on moved files, specify ops_path
-    if ops_path is not None:
-        ops['save_path'] = os.path.split(ops_path)[0]
-        ops['ops_path'] = ops_path 
-        if len(ops['fast_disk'])==0 or ops['save_path']!=ops['fast_disk']:
-            if os.path.exists(os.path.join(ops['save_path'], 'data.bin')):
-                ops['reg_file'] = os.path.join(ops['save_path'], 'data.bin')
-                if 'reg_file_chan2' in ops:
-                    ops['reg_file_chan2'] = os.path.join(ops['save_path'], 'data_chan2.bin')    
-                if 'raw_file' in ops:
-                    ops['raw_file'] = os.path.join(ops['save_path'], 'data_raw.bin')
-                if 'raw_file_chan2' in ops:
-                    ops['raw_file_chan2'] = os.path.join(ops['save_path'], 'data_chan2_raw.bin')
-
-    # check if registration should be done
-    if ops['do_registration']>0:
-        if 'refImg' not in ops or 'yoff' not in ops or ops['do_registration'] > 1:
-            print("NOTE: not registered / registration forced with ops['do_registration']>1")
-            try:
-                del ops['yoff'], ops['xoff'], ops['corrXY']  # delete previous offsets
-            except KeyError:
-                print('      (no previous offsets to delete)')
-            run_registration = True
-        else:
-            print("NOTE: not running registration, plane already registered")
-            print('binary path: %s'%ops['reg_file'])
-            run_registration = False
+    # Select file for classification
+    ops_classfile = ops.get('classifier_path')
+    builtin_classfile = classification.builtin_classfile
+    user_classfile = classification.user_classfile
+    if ops_classfile:
+        print(f'NOTE: applying classifier {str(ops_classfile)}')
+        classfile = ops_classfile
+    elif ops['use_builtin_classifier'] or not user_classfile.is_file():
+        print(f'NOTE: Applying builtin classifier at {str(builtin_classfile)}')
+        classfile = builtin_classfile
     else:
-        print("NOTE: not running registration, ops['do_registration']=0")
-        print('binary path: %s'%ops['reg_file'])
-        run_registration = False
-    
+        print(f'NOTE: applying default {str(user_classfile)}')
+        classfile = user_classfile
+
     if run_registration:
+        raw = f_raw is not None
+        # if already shifted by bidiphase, do not shift again
+        if not raw and ops['do_bidiphase'] and ops['bidiphase'] != 0:
+            ops['bidi_corrected'] = True
+        
         ######### REGISTRATION #########
         t11=time.time()
         print('----------- REGISTRATION')
         refImg = ops['refImg'] if 'refImg' in ops and ops.get('force_refImg', False) else None
-        ops = registration.register_binary(ops, refImg=refImg) # register binary
-        np.save(ops['ops_path'], ops)
+        
+        align_by_chan2 = ops['functional_chan'] != ops['align_by_chan']
+        registration_outputs = registration.register.registration_wrapper(f_reg, f_raw=f_raw, f_reg_chan2=f_reg_chan2, f_raw_chan2=f_raw_chan2, 
+                                                                            refImg=refImg, align_by_chan2=align_by_chan2, ops=ops)
+
+        ops = registration.register.save_registration_outputs_to_ops(registration_outputs, ops)
+        # add enhanced mean image
+        meanImgE = registration.register.compute_enhanced_mean_image(ops['meanImg'].astype(np.float32), ops)
+        ops['meanImgE'] = meanImgE
+
+        if ops.get('ops_path'):
+            np.save(ops['ops_path'], ops)
+
         plane_times['registration'] = time.time()-t11
         print('----------- Total %0.2f sec' % plane_times['registration'])
+        n_frames, Ly, Lx = f_reg.shape
 
         if ops['two_step_registration'] and ops['keep_movie_raw']:
             print('----------- REGISTRATION STEP 2')
             print('(making mean image (excluding bad frames)')
-            with io.BinaryFile(Lx=ops['Lx'], Ly=ops['Ly'], read_filename=ops['reg_file']) as f:
-                refImg = f.sampled_mean()
-            ops = registration.register_binary(ops, refImg, raw=False)
-            np.save(ops['ops_path'], ops)
+            nsamps = min(n_frames, 1000)
+            inds = np.linspace(0, n_frames, 1+nsamps).astype(np.int64)[:-1]
+            if align_by_chan2:
+                refImg = f_reg_chan2[inds].astype(np.float32).mean(axis=0)
+            else:
+                refImg = f_reg[inds].astype(np.float32).mean(axis=0)
+            registration_outputs = registration.register.registration_wrapper(f_reg, f_raw=None, f_reg_chan2=f_reg_chan2, f_raw_chan2=None, 
+                                                                                refImg=refImg, align_by_chan2=align_by_chan2, ops=ops)
+            if ops.get('ops_path'):
+                np.save(ops['ops_path'], ops)
             plane_times['two_step_registration'] = time.time()-t11
             print('----------- Total %0.2f sec' % plane_times['two_step_registration'])
 
         # compute metrics for registration
-        if ops.get('do_regmetrics', True) and ops['nframes']>=1500:
+        if ops.get('do_regmetrics', True) and n_frames>=1500:
             t0 = time.time()
-            ops = registration.get_pc_metrics(ops)
+            # n frames to pick from full movie
+            nsamp = min(2000 if n_frames < 5000 or Ly > 700 or Lx > 700 else 5000, n_frames)
+            inds = np.linspace(0, n_frames - 1, nsamp).astype('int')
+            mov = f_reg[inds]
+            mov = mov[:, ops['yrange'][0]:ops['yrange'][-1], ops['xrange'][0]:ops['xrange'][-1]]
+            ops = registration.get_pc_metrics(mov, ops)
             plane_times['registration_metrics'] = time.time()-t0
             print('Registration metrics, %0.2f sec.' % plane_times['registration_metrics'])
-            np.save(os.path.join(ops['save_path'], 'ops.npy'), ops)
+            if ops.get('ops_path'):
+                np.save(ops['ops_path'], ops)
     
     if ops.get('roidetect', True):
-
-        # Select file for classification
-        ops_classfile = ops.get('classifier_path')
-        builtin_classfile = classification.builtin_classfile
-        user_classfile = classification.user_classfile
-        if ops_classfile:
-            print(f'NOTE: applying classifier {str(ops_classfile)}')
-            classfile = ops_classfile
-        elif ops['use_builtin_classifier'] or not user_classfile.is_file():
-            print(f'NOTE: Applying builtin classifier at {str(builtin_classfile)}')
-            classfile = builtin_classfile
-        else:
-            print(f'NOTE: applying default {str(user_classfile)}')
-            classfile = user_classfile
-
+        n_frames, Ly, Lx = f_reg.shape
         ######## CELL DETECTION ##############
         t11=time.time()
         print('----------- ROI DETECTION')
         if stat is None:
-            ops, stat = detection.detect(ops=ops, classfile=classfile)
+            ops, stat = detection.detection_wrapper(f_reg,
+                                                    ops=ops, 
+                                                    classfile=classfile)
         plane_times['detection'] = time.time()-t11
         print('----------- Total %0.2f sec.' % plane_times['detection'])
 
         ######## ROI EXTRACTION ##############
         t11=time.time()
         print('----------- EXTRACTION')
-        ops, stat, F, Fneu, F_chan2, Fneu_chan2 = extraction.create_masks_and_extract(ops, stat)
+        stat, F, Fneu, F_chan2, Fneu_chan2 = extraction.extraction_wrapper(stat, f_reg, f_reg_chan2=f_reg_chan2, ops=ops)
         # save results
-        np.save(ops['ops_path'], ops)
-        fpath = ops['save_path']
-        np.save(os.path.join(fpath, 'stat.npy'), stat)
-        np.save(os.path.join(fpath,'F.npy'), F)
-        np.save(os.path.join(fpath,'Fneu.npy'), Fneu)
-        # if second channel, save F_chan2 and Fneu_chan2
-        if 'meanImg_chan2' in ops:
-            np.save(os.path.join(fpath, 'F_chan2.npy'), F_chan2)
-            np.save(os.path.join(fpath, 'Fneu_chan2.npy'), Fneu_chan2)
+        if ops.get('ops_path'):
+            np.save(ops['ops_path'], ops)
+
         plane_times['extraction'] = time.time()-t11
         print('----------- Total %0.2f sec.' % plane_times['extraction'])
 
@@ -270,10 +150,8 @@ def run_plane(ops, ops_path=None, stat=None):
             iscell = classification.classify(stat=stat, classfile=classfile)
         else:
             iscell = np.zeros((0, 2))
-        np.save(Path(ops['save_path']).joinpath('iscell.npy'), iscell)
         plane_times['classification'] = time.time()-t11
-        print('----------- Total %0.2f sec.' % plane_times['classification'])
-
+        
         ######### SPIKE DECONVOLUTION ###############
         fpath = ops['save_path']
         if ops.get('spikedetect', True):
@@ -294,18 +172,125 @@ def run_plane(ops, ops_path=None, stat=None):
         else:
             print("WARNING: skipping spike detection (ops['spikedetect']=False)")
             spks = np.zeros_like(F)
-        np.save(os.path.join(ops['save_path'], 'spks.npy'), spks)
 
+        if ops.get('save_path'):
+            fpath = ops['save_path']
+            np.save(os.path.join(fpath, 'stat.npy'), stat)
+            np.save(os.path.join(fpath,'F.npy'), F)
+            np.save(os.path.join(fpath,'Fneu.npy'), Fneu)
+            np.save(os.path.join(fpath, 'iscell.npy'), iscell)
+            np.save(os.path.join(ops['save_path'], 'spks.npy'), spks)
+            # if second channel, save F_chan2 and Fneu_chan2
+            if 'meanImg_chan2' in ops:
+                np.save(os.path.join(fpath, 'F_chan2.npy'), F_chan2)
+                np.save(os.path.join(fpath, 'Fneu_chan2.npy'), Fneu_chan2)
+        
         # save as matlab file
         if ops.get('save_mat'):
             stat = np.load(os.path.join(ops['save_path'], 'stat.npy'), allow_pickle=True)
             iscell = np.load(os.path.join(ops['save_path'], 'iscell.npy'))
             redcell = np.load(os.path.join(ops['save_path'], 'redcell.npy')) if ops['nchannels']==2 else []
             io.save_mat(ops, stat, F, Fneu, spks, iscell, redcell)
-            
     else:
         print("WARNING: skipping cell detection (ops['roidetect']=False)")
+    ops['timing'] = plane_times.copy()
+    plane_runtime = time.time()-t1
+    ops['timing']['total_plane_runtime'] = plane_runtime
+    if ops.get('ops_path'):
+        np.save(ops['ops_path'], ops)
 
+    return ops #, stat, F, Fneu, F_chan2, Fneu_chan2, spks, iscell, redcell
+    
+
+def run_plane(ops, ops_path=None, stat=None):
+    """ run suite2p processing on a single binary file
+
+    Parameters
+    -----------
+    ops : :obj:`dict` 
+        specify 'reg_file', 'nchannels', 'tau', 'fs'
+
+    ops_path: str
+        absolute path to ops file (use if files were moved)
+
+    stat: list of `dict`
+        ROIs
+
+    Returns
+    --------
+    ops : :obj:`dict` 
+    """
+    
+    ops = {**default_ops(), **ops}
+    ops['date_proc'] = datetime.now()
+    
+    # for running on server or on moved files, specify ops_path
+    if ops_path is not None:
+        ops['save_path'] = os.path.split(ops_path)[0]
+        ops['ops_path'] = ops_path 
+        if len(ops['fast_disk'])==0 or ops['save_path']!=ops['fast_disk']:
+            if os.path.exists(os.path.join(ops['save_path'], 'data.bin')):
+                ops['reg_file'] = os.path.join(ops['save_path'], 'data.bin')
+                if 'reg_file_chan2' in ops:
+                    ops['reg_file_chan2'] = os.path.join(ops['save_path'], 'data_chan2.bin')    
+                if 'raw_file' in ops:
+                    ops['raw_file'] = os.path.join(ops['save_path'], 'data_raw.bin')
+                if 'raw_file_chan2' in ops:
+                    ops['raw_file_chan2'] = os.path.join(ops['save_path'], 'data_chan2_raw.bin')
+
+    # check that there are sufficient numbers of frames
+    if ops['nframes'] < 50:
+        raise ValueError('the total number of frames should be at least 50.')
+    if ops['nframes'] < 200:
+        print('WARNING: number of frames is below 200, unpredictable behaviors may occur.')
+
+    # check if registration should be done
+    if ops['do_registration']>0:
+        if 'refImg' not in ops or 'yoff' not in ops or ops['do_registration'] > 1:
+            print("NOTE: not registered / registration forced with ops['do_registration']>1")
+            try:
+                del ops['yoff'], ops['xoff'], ops['corrXY']  # delete previous offsets
+            except KeyError:
+                print('      (no previous offsets to delete)')
+            run_registration = True
+        else:
+            print("NOTE: not running registration, plane already registered")
+            print('binary path: %s'%ops['reg_file'])
+            run_registration = False
+    else:
+        print("NOTE: not running registration, ops['do_registration']=0")
+        print('binary path: %s'%ops['reg_file'])
+        run_registration = False
+
+    Ly, Lx = ops['Ly'], ops['Lx']
+    
+    # get binary file paths
+    raw = ops.get('keep_movie_raw') and 'raw_file' in ops and os.path.isfile(ops['raw_file'])
+    reg_file = ops['reg_file']
+    raw_file = ops.get('raw_file', 0) if raw else reg_file
+    if ops['nchannels'] > 1:
+        reg_file_chan2 = ops['reg_file_chan2']
+        raw_file_chan2 = ops.get('raw_file_chan2', 0) if raw else reg_file_chan2
+    else:
+        reg_file_chan2 = reg_file 
+        raw_file_chan2 = reg_file   
+        
+
+    with io.BinaryRWFile(Ly=Ly, Lx=Lx, filename=raw_file if raw else reg_file) as f_raw, \
+         io.BinaryRWFile(Ly=Ly, Lx=Lx, filename=reg_file) as f_reg, \
+         io.BinaryRWFile(Ly=Ly, Lx=Lx, filename=raw_file_chan2 if raw else reg_file_chan2) as f_raw_chan2,\
+         io.BinaryRWFile(Ly=Ly, Lx=Lx, filename=reg_file_chan2) as f_reg_chan2:         
+        if not raw:
+            f_raw.close()
+            f_raw = None
+            f_raw_chan2.close()
+            f_raw_chan2 = None
+        if ops['nchannels'] == 1:
+            f_reg_chan2.close() 
+            f_reg_chan2 = None
+
+        ops = pipeline(f_reg, f_raw, f_reg_chan2, f_raw_chan2, run_registration, ops, stat=stat)
+        
     if ops.get('move_bin') and ops['save_path'] != ops['fast_disk']:
         print('moving binary files to save_path')
         shutil.move(ops['reg_file'], os.path.join(ops['save_path'], 'data.bin'))
@@ -324,10 +309,6 @@ def run_plane(ops, ops_path=None, stat=None):
             os.remove(ops['raw_file'])
             if ops['nchannels'] > 1:
                 os.remove(ops['raw_file_chan2'])
-    ops['timing'] = plane_times.copy()
-    plane_runtime = time.time()-t1
-    ops['timing']['total_plane_runtime'] = plane_runtime
-    np.save(ops['ops_path'], ops)
     return ops
 
 
